@@ -289,45 +289,63 @@ sub search {
       if ($dir && -d $dir) { $SDCommon::c{$var}=$dir; return;}
    }
    for (@testsvn) {
-     printf (_g("Looking in SVN for: %s\n", $_));
+     printf (_g("Looking in SVN for: %s\n"), $_);
+     # print "($_)" if $SDCommon::opt_verbose;
       if ($_ && insvn($_)) { 
          printf (_g("I: adding the URLs to the '%s' to skip the check later.\n"), $cfgFile) if(!$SDCommon::opt_nosave);
          $SDCommon::c{$var}=insvn($_);
          return;
       }
       else {
-         print _g("Failed, assuming non-existent directory...");
+         print _g("Failed, assuming non-existent directory...")."\n";
       }
    }
 }
 
+sub get_probe_set
+{
+   my @probeset=(url("."));
+   push(@probeset, "$1/$package") if $probeset[0]=~/(.*)\/branches\//;
+   return @probeset;
+}
+
 # if still undefined, try blind search in the repository
 sub needs_upsTagUrl {
-   search("branches","upstream", "upsTagUrl", url("."));
-   exwerror sprintf(_g("upsTagUrl setting is required, but could not be found in %s or repository tree."), $cfgFile) if (!defined $SDCommon::c{"upsTagUrl"});
+   return 1 if defined $SDCommon::c{"upsTagUrl"};
+   foreach my $hereurl (get_probe_set())
+   {
+      search("branches","upstream", "upsTagUrl", $hereurl);
+      return 1 if defined $SDCommon::c{"upsTagUrl"};
+   }
+   exwerror sprintf(_g("upsTagUrl setting is required, but could not be found in %s or repository tree."), $cfgFile);
 }
 sub needs_upsCurrentUrl {
-   search("branches","upstream/current", "upsCurrentUrl", url("."));
-   if( !defined $SDCommon::c{"upsCurrentUrl"} ) { # maybe layout 2?
-        search("branches/upstream","current", "upsCurrentUrl", url("."));
+   return 1 if defined $SDCommon::c{"upsCurrentUrl"};
+   foreach my $hereurl (get_probe_set())
+   {
+      search("branches","upstream/current", "upsCurrentUrl", $hereurl);
+      if( !defined $SDCommon::c{"upsCurrentUrl"} ) { # maybe layout 2?
+         search("branches/upstream","current", "upsCurrentUrl", $hereurl);
+      }
+      return 1 if defined $SDCommon::c{"upsTagUrl"};
    }
-    # Translators: %s is the name of the config file.
-   exwerror sprintf (_g("upsCurrentUrl setting is required, but could not be found in %s or repository tree."), $cfgFile) if (!defined $SDCommon::c{"upsCurrentUrl"});
+   # Translators: %s is the name of the config file.
+   exwerror sprintf (_g("upsCurrentUrl setting is required, but could not be found in %s or repository tree."), $cfgFile);
 }
 sub needs_tagsUrl {
-    my $hereurl=url(".");
-    search("tags", "", "tagsUrl", $hereurl);
-    if( !defined $SDCommon::c{"tagsUrl"} && $hereurl=~/(.*)\/branches\// ) { # oh, crap...
-        print _g("Branch directory detected in URL, testing more possible locations\n");
-        search("tags", "", "tagsUrl", "$1/$package");
-    }
+   return 1 if defined $SDCommon::c{"tagsUrl"};
+   foreach my $hereurl (get_probe_set())
+   {
+      search("tags", "", "tagsUrl", $hereurl);
+      return 1 if defined $SDCommon::c{"tagsUrl"};
+   }
     # Translators: %s is the name of the config file.
-    exwerror sprintf (_g("tagsUrl setting is required, but could not be found in %s or repository tree."), $cfgFile) if (!defined $SDCommon::c{"tagsUrl"});
+    exwerror sprintf (_g("tagsUrl setting is required, but could not be found in %s or repository tree."), $cfgFile);
 }
 sub writeCfg {
    my $cfgFile = shift;
     # Translators: %s is the name of the config file.
-   printf (_g("I: Configuration saving was overrided (%s should be intact).\n"), $cfgFile) if ($SDCommon::opt_nosave==1 and (defined $SDCommon::opt_verbose) );
+   printf (_g("I: Configuration saving was overriden (%s should be intact).\n"), $cfgFile) if ($SDCommon::opt_nosave==1 and (defined $SDCommon::opt_verbose) );
    return 1 if $SDCommon::opt_nosave==1;
    if($_[0]){$cfgFile = $_[0];}
     # Translators: %s is the name of the config file.
